.. ODCS documentation master file, created by
   sphinx-quickstart on Wed May 10 13:18:15 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=========
ODCS
=========

The ODCS (On Demand Compose Service) is a service allowing to generate temporary
compose (mainly the RPM repository) with packages from Koji using the REST API.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   about
   client
   module
   api
   raw_config

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _ODCS: https://pagure.io/odcs
